
from nose.tools import eq_

import inflect


def test_join():
    p = inflect.engine()

    # Three words...
    words = "apple banana carrot".split()

    eq_(p.join(words),
        "apple, banana, and carrot", msg='plain 3 words')

    eq_(p.join(words, final_sep=''),
        "apple, banana and carrot", msg='3 words, no final sep')

    eq_(p.join(words, final_sep='...'),
        "apple, banana... and carrot", msg='3 words, different final sep')

    eq_(p.join(words, final_sep='...', conj=''),
        "apple, banana... carrot", msg='-->%s != %s<--   3 words, different final sep, no conjunction' %
        (p.join(words, final_sep='...', conj=''), "apple, banana... carrot"))

    eq_(p.join(words, conj='or'),
        "apple, banana, or carrot", msg='%s != %s    3 words, different conjunction' % (p.join(words, conj='or'),
        "apple, banana, or carrot"))

    # Three words with semicolons...
    words = ('apple,fuji', 'banana', 'carrot')

    eq_(p.join(words),
        "apple,fuji; banana; and carrot",
        msg='%s != %s<-- comma-inclusive 3 words' % (p.join(words), "apple,fuji, banana; and carrot"))

    eq_(p.join(words, final_sep=''),
        "apple,fuji; banana and carrot", msg='join(%s) == "%s" != "%s"' % (words, p.join(words, final_sep=''),
                                                                           "apple,fuji) banana and carrot"))

    eq_(p.join(words, final_sep='...'),
        "apple,fuji; banana... and carrot", msg='comma-inclusive 3 words, different final sep')

    eq_(p.join(words, final_sep='...', conj=''),
        "apple,fuji; banana... carrot", msg='comma-inclusive 3 words, different final sep, no conjunction')

    eq_(p.join(words, conj='or'),
        "apple,fuji; banana; or carrot", msg='comma-inclusive 3 words, different conjunction')

    # Two words...
    words = ('apple', 'carrot')

    eq_(p.join(words),
        "apple and carrot", msg='plain 2 words')

    eq_(p.join(words, final_sep=''),
        "apple and carrot", msg='2 words, no final sep')

    eq_(p.join(words, final_sep='...'),
        "apple and carrot", msg='2 words, different final sep')

    eq_(p.join(words, final_sep='...', conj=''),
        "apple carrot", msg="join(%s, final_sep='...', conj='') == %s != %s" % (
            words, p.join(words, final_sep='...', conj=''), 'apple carrot'))

    eq_(p.join(words, final_sep='...', conj='', conj_spaced=False),
        "applecarrot", msg="join(%s, final_sep='...', conj='') == %s != %s" % (
            words, p.join(words, final_sep='...', conj=''), 'applecarrot'))

    eq_(p.join(words, conj='or'),
        "apple or carrot", msg='2 words, different conjunction')

    # One word...
    words = ['carrot']

    eq_(p.join(words),
        "carrot", msg='plain 1 word')

    eq_(p.join(words, final_sep=''),
        "carrot", msg='1 word, no final sep')

    eq_(p.join(words, final_sep='...'),
        "carrot", msg='1 word, different final sep')

    eq_(p.join(words, final_sep='...', conj=''),
        "carrot", msg='1 word, different final sep, no conjunction')

    eq_(p.join(words, conj='or'),
        "carrot", msg='1 word, different conjunction')



from nose.tools import eq_

import inflect


class TestCompounds(object):
    def setup(self):
        self.p = inflect.engine()

    def test_compound_1(self):
        eq_(self.p.singular_noun('hello-out-there'), 'hello-out-there')

    def test_compound_2(self):
        eq_(self.p.singular_noun('hello out there'), 'hello out there')

    def test_compound_3(self):
        eq_(self.p.singular_noun('continue-to-operate'), 'continue-to-operate')

    def test_compound_4(self):
        eq_(self.p.singular_noun('case of diapers'), 'case of diapers')



#!/usr/bin/python

import unittest

from inflect import (BadChunkingOptionError, NumOutOfRangeError, BadNumValueError, BadGenderError,
                     UnknownClassicalModeError)
import inflect


class test(unittest.TestCase):
    def TODO(self, ans, answer_wanted,
             answer_gives_now="default_that_will_never_occur__can't_use_None_as_that_is_a_possible_valid_value"):
        '''
        make this test for future testing

        so can easily rename these to assertEqual when code ready
        '''
        if ans == answer_wanted:
            print('test unexpectedly passed!: %s == %s' % (ans, answer_wanted))
        if answer_gives_now != "default_that_will_never_occur__can't_use_None_as_that_is_a_possible_valid_value":
            self.assertEqual(ans, answer_gives_now)

    def test_enclose(self):
        # def enclose
        self.assertEqual(inflect.enclose("test"), "(?:test)")

    def test_joinstem(self):
        # def joinstem
        self.assertEqual(inflect.joinstem(-2, ["ephemeris", "iris", ".*itis"]),
                         '(?:ephemer|ir|.*it)')

    def test_classical(self):
        # classical dicts
        self.assertEqual(set(inflect.def_classical.keys()), set(inflect.all_classical.keys()))
        self.assertEqual(set(inflect.def_classical.keys()), set(inflect.no_classical.keys()))

        # def classical
        p = inflect.engine()
        self.assertEqual(p.classical_dict, inflect.def_classical)

        p.classical()
        self.assertEqual(p.classical_dict, inflect.all_classical)

        self.assertRaises(TypeError, p.classical, 0)
        self.assertRaises(TypeError, p.classical, 1)
        self.assertRaises(TypeError, p.classical, 'names')
        self.assertRaises(TypeError, p.classical, 'names', 'zero')
        self.assertRaises(TypeError, p.classical, 'all')

        p.classical(all=False)
        self.assertEqual(p.classical_dict, inflect.no_classical)

        p.classical(names=True, zero=True)
        mydict = inflect.def_classical.copy()
        mydict.update(dict(names=1, zero=1))
        self.assertEqual(p.classical_dict, mydict)

        p.classical(all=True)
        self.assertEqual(p.classical_dict, inflect.all_classical)

        p.classical(all=False)
        p.classical(names=True, zero=True)
        mydict = inflect.def_classical.copy()
        mydict.update(dict(names=True, zero=True))
        self.assertEqual(p.classical_dict, mydict)

        p.classical(all=False)
        p.classical(names=True, zero=False)
        mydict = inflect.def_classical.copy()
        mydict.update(dict(names=True, zero=False))
        self.assertEqual(p.classical_dict, mydict)

        self.assertRaises(UnknownClassicalModeError, p.classical, bogus=True)

    def test_num(self):
        # def num
        p = inflect.engine()
        self.assertTrue(p.persistent_count is None)

        p.num()
        self.assertTrue(p.persistent_count is None)

        ret = p.num(3)
        self.assertEqual(p.persistent_count, 3)
        self.assertEqual(ret, '3')

        p.num()
        ret = p.num("3")
        self.assertEqual(p.persistent_count, 3)
        self.assertEqual(ret, '3')

        p.num()
        ret = p.num(count=3, show=1)
        self.assertEqual(p.persistent_count, 3)
        self.assertEqual(ret, '3')

        p.num()
        ret = p.num(count=3, show=0)
        self.assertEqual(p.persistent_count, 3)
        self.assertEqual(ret, '')

        self.assertRaises(BadNumValueError, p.num, 'text')

    def test_inflect(self):
        p = inflect.engine()
        for txt, ans in (
            ("num(1)", "1"),
            ("num(1,0)", "1"),
            ("num(1,1)", "1"),
            ("num(1)   ", "1   "),
            ("   num(1)   ", "   1   "),
            ("num(3) num(1)", "3 1"),
        ):
            self.assertEqual(p.inflect(txt), ans, msg='p.inflect("%s") != "%s"' % (txt, ans))

        for txt, ans in (
            ("plural(rock)", "rocks"),
            ("plural(rock)  plural(child)", "rocks  children"),
            ("num(2) plural(rock)  plural(child)", "2 rocks  children"),

            ("plural(rock) plural_noun(rock) plural_verb(rocks) plural_adj(big) a(ant)",
             "rocks rocks rock big an ant"),

            ("an(rock) no(cat) ordinal(3) number_to_words(1234) present_participle(runs)",
             "a rock no cats 3rd one thousand, two hundred and thirty-four running"),

            # TODO: extra space when space before number. Is this desirable?
            ("a(cat,0) a(cat,1) a(cat,2) a(cat, 2)", "0 cat a cat 2 cat  2 cat"),
        ):
            self.assertEqual(p.inflect(txt), ans, msg='p.inflect("%s") != "%s"' % (txt, ans))

    def test_user_input_fns(self):
        p = inflect.engine()

        self.assertEqual(p.pl_sb_user_defined, [])
        p.defnoun('VAX', 'VAXen')
        self.assertEqual(p.plural('VAX'), 'VAXEN')
        self.assertEqual(p.pl_sb_user_defined, ['VAX', 'VAXen'])

        self.assertTrue(p.ud_match('word', p.pl_sb_user_defined)
                        is None)
        self.assertEqual(p.ud_match('VAX', p.pl_sb_user_defined),
                         'VAXen')
        self.assertTrue(p.ud_match('VVAX', p.pl_sb_user_defined)
                        is None)

        p.defnoun('cow', 'cows|kine')
        self.assertEqual(p.plural('cow'), 'cows')
        p.classical()
        self.assertEqual(p.plural('cow'), 'kine')

        self.assertEqual(p.ud_match('cow', p.pl_sb_user_defined),
                         'cows|kine')

        p.defnoun('(.+i)o', r'$1i')
        self.assertEqual(p.plural('studio'), 'studii')
        self.assertEqual(p.ud_match('studio', p.pl_sb_user_defined),
                         'studii')

        p.defnoun('aviatrix', 'aviatrices')
        self.assertEqual(p.plural('aviatrix'), 'aviatrices')
        self.assertEqual(p.ud_match('aviatrix', p.pl_sb_user_defined),
                         'aviatrices')
        p.defnoun('aviatrix', 'aviatrixes')
        self.assertEqual(p.plural('aviatrix'), 'aviatrixes')
        self.assertEqual(p.ud_match('aviatrix', p.pl_sb_user_defined),
                         'aviatrixes')
        p.defnoun('aviatrix', None)
        self.assertEqual(p.plural('aviatrix'), 'aviatrices')
        self.assertEqual(p.ud_match('aviatrix', p.pl_sb_user_defined),
                         None)

        p.defnoun('(cat)', r'$1s')
        self.assertEqual(p.plural('cat'), 'cats')

        inflect.STDOUT_ON = False
        self.assertRaises(inflect.BadUserDefinedPatternError, p.defnoun, '(??', None)
        inflect.STDOUT_ON = True

        p.defnoun(None, '')  # check None doesn't crash it

        # defverb
        p.defverb('will', 'shall',
                  'will', 'will',
                  'will', 'will')
        self.assertEqual(p.ud_match('will', p.pl_v_user_defined),
                         'will')
        self.assertEqual(p.plural('will'), 'will')
        # TODO: will -> shall. Tests below fail
        self.TODO(p.compare('will', 'shall'), 's:p')
        self.TODO(p.compare_verbs('will', 'shall'), 's:p')

        # defadj
        p.defadj('hir', 'their')
        self.assertEqual(p.plural('hir'), 'their')
        self.assertEqual(p.ud_match('hir', p.pl_adj_user_defined), 'their')

        # defa defan
        p.defa('h')
        self.assertEqual(p.a('h'), 'a h')
        self.assertEqual(p.ud_match('h', p.A_a_user_defined), 'a')

        p.defan('horrendous.*')
        self.assertEqual(p.a('horrendously'), 'an horrendously')
        self.assertEqual(p.ud_match('horrendously', p.A_a_user_defined), 'an')

    def test_postprocess(self):
        p = inflect.engine()
        for orig, infl, txt in (
            ('cow', 'cows', 'cows'),
            ('I', 'we', 'we'),
            ('COW', 'cows', 'COWS'),
            ('Cow', 'cows', 'Cows'),
            ('cow', 'cows|kine', 'cows'),
        ):
            self.assertEqual(p.postprocess(orig, infl), txt)

        p.classical()
        self.assertEqual(p.postprocess('cow', 'cows|kine'), 'kine')

    def test_partition_word(self):
        p = inflect.engine()
        for txt, part in (
            (' cow ', (' ', 'cow', ' ')),
            ('cow', ('', 'cow', '')),
            ('   cow', ('   ', 'cow', '')),
            ('cow   ', ('', 'cow', '   ')),
            ('  cow   ', ('  ', 'cow', '   ')),
            ('', ('', '', '')),
            ('bottle of beer', ('', 'bottle of beer', '')),
            # spaces give weird results
            # (' '),('', ' ', '')),
            # ('  '),(' ', ' ', '')),
            # ('   '),('  ', ' ', '')),
        ):
            self.assertEqual(p.partition_word(txt), part)

    def test_pl(self):
        p = inflect.engine()
        for fn, sing, plur in (
            (p.plural, '', ''),
            (p.plural, 'cow', 'cows'),
            (p.plural, 'thought', 'thoughts'),
            (p.plural, 'mouse', 'mice'),
            (p.plural, 'knife', 'knives'),
            (p.plural, 'knifes', 'knife'),
            (p.plural, ' cat  ', ' cats  '),
            (p.plural, 'court martial', 'courts martial'),
            (p.plural, 'a', 'some'),
            (p.plural, 'carmen', 'carmina'),
            (p.plural, 'quartz', 'quartzes'),
            (p.plural, 'care', 'cares'),
            (p.plural_noun, '', ''),
            (p.plural_noun, 'cow', 'cows'),
            (p.plural_noun, 'thought', 'thoughts'),
            (p.plural_verb, '', ''),
            (p.plural_verb, 'runs', 'run'),
            (p.plural_verb, 'thought', 'thought'),
            (p.plural_verb, 'eyes', 'eye'),
            (p.plural_adj, '', ''),
            (p.plural_adj, 'a', 'some'),
            (p.plural_adj, 'this', 'these'),
            (p.plural_adj, 'that', 'those'),
            (p.plural_adj, 'my', 'our'),
            (p.plural_adj, "cat's", "cats'"),
            (p.plural_adj, "child's", "children's"),
        ):
            self.assertEqual(fn(sing), plur,
                             msg='%s("%s") == "%s" != "%s"' % (
                                 fn.__name__, sing, fn(sing), plur))

        for sing, num, plur in (
            ('cow', 1, 'cow'),
            ('cow', 2, 'cows'),
            ('cow', 'one', 'cow'),
            ('cow', 'each', 'cow'),
            ('cow', 'two', 'cows'),
            ('cow', 0, 'cows'),
            ('cow', 'zero', 'cows'),
            ('runs', 0, 'run'),
            ('runs', 1, 'runs'),
            ('am', 0, 'are'),
        ):
            self.assertEqual(p.plural(sing, num), plur)

        p.classical(zero=True)
        self.assertEqual(p.plural('cow', 0), 'cow')
        self.assertEqual(p.plural('cow', 'zero'), 'cow')
        self.assertEqual(p.plural('runs', 0), 'runs')
        self.assertEqual(p.plural('am', 0), 'am')
        self.assertEqual(p.plural_verb('runs', 1), 'runs')

        self.assertEqual(p.plural('die'), 'dice')
        self.assertEqual(p.plural_noun('die'), 'dice')

    def test_sinoun(self):
        p = inflect.engine()
        for sing, plur in (
            ('cat', 'cats'),
            ('die', 'dice'),
        ):
            self.assertEqual(p.singular_noun(plur), sing)
            self.assertEqual(p.inflect('singular_noun(%s)' % plur), sing)

    def test_gender(self):
        p = inflect.engine()
        p.gender('feminine')
        for sing, plur in (
            ('she', 'they'),
            ('herself', 'themselves'),
            ('hers', 'theirs'),
            ('to her', 'to them'),
            ('to herself', 'to themselves'),
        ):
            self.assertEqual(p.singular_noun(plur), sing,
                             "singular_noun(%s) == %s != %s" % (plur, p.singular_noun(plur), sing))
            self.assertEqual(p.inflect('singular_noun(%s)' % plur), sing)

        p.gender('masculine')
        for sing, plur in (
            ('he', 'they'),
            ('himself', 'themselves'),
            ('his', 'theirs'),
            ('to him', 'to them'),
            ('to himself', 'to themselves'),
        ):
            self.assertEqual(p.singular_noun(plur), sing,
                             "singular_noun(%s) == %s != %s" % (plur, p.singular_noun(plur), sing))
            self.assertEqual(p.inflect('singular_noun(%s)' % plur), sing)

        p.gender('gender-neutral')
        for sing, plur in (
            ('they', 'they'),
            ('themself', 'themselves'),
            ('theirs', 'theirs'),
            ('to them', 'to them'),
            ('to themself', 'to themselves'),
        ):
            self.assertEqual(p.singular_noun(plur), sing,
                             "singular_noun(%s) == %s != %s" % (plur, p.singular_noun(plur), sing))
            self.assertEqual(p.inflect('singular_noun(%s)' % plur), sing)

        p.gender('neuter')
        for sing, plur in (
            ('it', 'they'),
            ('itself', 'themselves'),
            ('its', 'theirs'),
            ('to it', 'to them'),
            ('to itself', 'to themselves'),
        ):
            self.assertEqual(p.singular_noun(plur), sing,
                             "singular_noun(%s) == %s != %s" % (plur, p.singular_noun(plur), sing))
            self.assertEqual(p.inflect('singular_noun(%s)' % plur), sing)

        self.assertRaises(BadGenderError, p.gender, 'male')

        for sing, plur, gen in (
            ('it', 'they', 'neuter'),
            ('she', 'they', 'feminine'),
            ('he', 'they', 'masculine'),
            ('they', 'they', 'gender-neutral'),
            ('she or he', 'they', 'feminine or masculine'),
            ('he or she', 'they', 'masculine or feminine'),
        ):
            self.assertEqual(p.singular_noun(plur, gender=gen), sing)

    def test_plequal(self):
        p = inflect.engine()
        for fn, sing, plur, res in (
            (p.compare, 'index', 'index', 'eq'),
            (p.compare, 'index', 'indexes', 's:p'),
            (p.compare, 'index', 'indices', 's:p'),
            (p.compare, 'indexes', 'index', 'p:s'),
            (p.compare, 'indices', 'index', 'p:s'),
            (p.compare, 'indices', 'indexes', 'p:p'),
            (p.compare, 'indexes', 'indices', 'p:p'),
            (p.compare, 'indices', 'indices', 'eq'),
            (p.compare, 'opuses', 'opera', 'p:p'),
            (p.compare, 'opera', 'opuses', 'p:p'),
            (p.compare, 'brothers', 'brethren', 'p:p'),
            (p.compare, 'cats', 'cats', 'eq'),
            (p.compare, 'base', 'basis', False),
            (p.compare, 'syrinx', 'syringe', False),
            (p.compare, 'she', 'he', False),
            (p.compare, 'opus', 'operas', False),
            (p.compare, 'taxi', 'taxes', False),
            (p.compare, 'time', 'Times', False),
            (p.compare, 'time'.lower(), 'Times'.lower(), 's:p'),
            (p.compare, 'courts martial', 'court martial', 'p:s'),
            (p.compare, 'my', 'my', 'eq'),
            (p.compare, 'my', 'our', 's:p'),
            (p.compare, 'our', 'our', 'eq'),
            (p.compare_nouns, 'index', 'index', 'eq'),
            (p.compare_nouns, 'index', 'indexes', 's:p'),
            (p.compare_nouns, 'index', 'indices', 's:p'),
            (p.compare_nouns, 'indexes', 'index', 'p:s'),
            (p.compare_nouns, 'indices', 'index', 'p:s'),
            (p.compare_nouns, 'indices', 'indexes', 'p:p'),
            (p.compare_nouns, 'indexes', 'indices', 'p:p'),
            (p.compare_nouns, 'indices', 'indices', 'eq'),
            (p.compare_verbs, 'runs', 'runs', 'eq'),
            (p.compare_verbs, 'runs', 'run', 's:p'),
            (p.compare_verbs, 'run', 'run', 'eq'),
            (p.compare_adjs, 'my', 'my', 'eq'),
            (p.compare_adjs, 'my', 'our', 's:p'),
            (p.compare_adjs, 'our', 'our', 'eq'),
        ):
            self.assertEqual(fn(sing, plur), res)

        for fn, sing, plur, res, badres in (
            (p.compare, "dresses's", "dresses'", 'p:p', 'p:s'),  # TODO: should return p:p
            (p.compare_adjs, "dresses's", "dresses'", 'p:p', False),  # TODO: should return p:p

            # TODO: future: support different singulars one day.
            (p.compare, "dress's", "dress'", 's:s', 'p:s'),
            (p.compare_adjs, "dress's", "dress'", 's:s', False),
            (p.compare, "Jess's", "Jess'", 's:s', 'p:s'),
            (p.compare_adjs, "Jess's", "Jess'", 's:s', False),
        ):
            self.TODO(fn(sing, plur), res, badres)

        # TODO: pass upstream. multiple adjective plurals not supported
        self.assertEqual(p.compare('your', 'our'), False)
        p.defadj('my', 'our|your')  # what's ours is yours
        self.TODO(p.compare('your', 'our'), 'p:p')

    def test__pl_reg_plurals(self):
        p = inflect.engine()
        for pair, stems, end1, end2, ans in (
            ('indexes|indices', 'dummy|ind', 'exes', 'ices', True),
            ('indexes|robots', 'dummy|ind', 'exes', 'ices', False),
            ('beaus|beaux', '.*eau', 's', 'x', True),
        ):
            self.assertEqual(p._pl_reg_plurals(pair, stems, end1, end2), ans)

    def test__pl_check_plurals_N(self):
        p = inflect.engine()
        self.assertEqual(p._pl_check_plurals_N('index', 'indices'), False)
        self.assertEqual(p._pl_check_plurals_N('indexes', 'indices'), True)
        self.assertEqual(p._pl_check_plurals_N('indices', 'indexes'), True)
        self.assertEqual(p._pl_check_plurals_N('stigmata', 'stigmas'), True)
        self.assertEqual(p._pl_check_plurals_N('phalanxes', 'phalanges'), True)

    def test__pl_check_plurals_adj(self):
        p = inflect.engine()
        self.assertEqual(p._pl_check_plurals_adj("indexes's", "indices's"), True)
        self.assertEqual(p._pl_check_plurals_adj("indices's", "indexes's"), True)
        self.assertEqual(p._pl_check_plurals_adj("indexes'", "indices's"), True)
        self.assertEqual(p._pl_check_plurals_adj("indexes's", "indices'"), True)
        self.assertEqual(p._pl_check_plurals_adj("indexes's", "indexes's"), False)
        self.assertEqual(p._pl_check_plurals_adj("dogmas's", "dogmata's"), True)
        self.assertEqual(p._pl_check_plurals_adj("dogmas'", "dogmata'"), True)
        self.assertEqual(p._pl_check_plurals_adj("indexes'", "indices'"), True)

    def test_count(self):
        p = inflect.engine()
        for txt, num in (
            (1, 1),
            (2, 2),
            (0, 2),
            (87, 2),
            (-7, 2),
            ('1', 1),
            ('2', 2),
            ('0', 2),
            ('no', 2),
            ('zero', 2),
            ('nil', 2),
            ('a', 1),
            ('an', 1),
            ('one', 1),
            ('each', 1),
            ('every', 1),
            ('this', 1),
            ('that', 1),
            ('dummy', 2),
        ):
            self.assertEqual(p.get_count(txt), num)

        self.assertEqual(p.get_count(), '')
        p.num(3)
        self.assertEqual(p.get_count(), 2)

    def test__plnoun(self):
        p = inflect.engine()
        for sing, plur in (
            ('', ''),
            ('tuna', 'tuna'),
            ('TUNA', 'TUNA'),
            ('swordfish', 'swordfish'),
            ('Governor General', 'Governors General'),
            ('Governor-General', 'Governors-General'),
            ('Major General', 'Major Generals'),
            ('Major-General', 'Major-Generals'),
            ('mother in law', 'mothers in law'),
            ('mother-in-law', 'mothers-in-law'),
            ('about me', 'about us'),
            ('to it', 'to them'),
            ('from it', 'from them'),
            ('with it', 'with them'),
            ('I', 'we'),
            ('you', 'you'),
            ('me', 'us'),
            ('mine', 'ours'),
            ('child', 'children'),
            ('brainchild', 'brainchilds'),
            ('human', 'humans'),
            ('soliloquy', 'soliloquies'),

            ('chairwoman', 'chairwomen'),
            ('goose', 'geese'),
            ('tooth', 'teeth'),
            ('foot', 'feet'),
            ('forceps', 'forceps'),
            ('protozoon', 'protozoa'),
            ('czech', 'czechs'),
            ('codex', 'codices'),
            ('radix', 'radices'),
            ('bacterium', 'bacteria'),
            ('alumnus', 'alumni'),
            ('criterion', 'criteria'),
            ('alumna', 'alumnae'),

            ('bias', 'biases'),
            ('quiz', 'quizzes'),
            ('fox', 'foxes'),

            ('shelf', 'shelves'),
            ('leaf', 'leaves'),
            ('midwife', 'midwives'),
            ('scarf', 'scarves'),

            ('key', 'keys'),
            ('Sally', 'Sallys'),
            ('sally', 'sallies'),

            ('ado', 'ados'),
            ('auto', 'autos'),
            ('alto', 'altos'),
            ('zoo', 'zoos'),
            ('tomato', 'tomatoes'),
        ):
            self.assertEqual(p._plnoun(sing), plur,
                             msg='p._plnoun("%s") == %s != "%s"' % (
                                 sing, p._plnoun(sing), plur))

            self.assertEqual(p._sinoun(plur), sing,
                             msg='p._sinoun("%s") != "%s"' % (plur, sing))

        # words where forming singular is ambiguious or not attempted
        for sing, plur in (
            ('son of a gun', 'sons of guns'),
            ('son-of-a-gun', 'sons-of-guns'),
            ('basis', 'bases'),
            ('Jess', 'Jesses'),
        ):
            self.assertEqual(p._plnoun(sing), plur,
                             msg='p._plnoun("%s") != "%s"' % (sing, plur))

        for sing, plur in (
            # TODO: does not keep case
            ('about ME', 'about US'),
            # TODO: does not keep case
            ('YOU', 'YOU'),
        ):
            self.TODO(p._plnoun(sing), plur)

        p.num(1)
        self.assertEqual(p._plnoun('cat'), 'cat')
        p.num(3)

        p.classical(herd=True)
        self.assertEqual(p._plnoun('swine'), 'swine')
        p.classical(herd=False)
        self.assertEqual(p._plnoun('swine'), 'swines')
        p.classical(persons=True)
        self.assertEqual(p._plnoun('chairperson'), 'chairpersons')
        p.classical(persons=False)
        self.assertEqual(p._plnoun('chairperson'), 'chairpeople')
        p.classical(ancient=True)
        self.assertEqual(p._plnoun('formula'), 'formulae')
        p.classical(ancient=False)
        self.assertEqual(p._plnoun('formula'), 'formulas')

        p.classical()
        for sing, plur in (
            ('matrix', 'matrices'),
            ('gateau', 'gateaux'),
            ('millieu', 'millieux'),
            ('syrinx', 'syringes'),

            ('stamen', 'stamina'),
            ('apex', 'apices'),
            ('appendix', 'appendices'),
            ('maximum', 'maxima'),
            ('focus', 'foci'),
            ('status', 'status'),
            ('aurora', 'aurorae'),
            ('soma', 'somata'),
            ('iris', 'irides'),
            ('solo', 'soli'),
            ('oxymoron', 'oxymora'),
            ('goy', 'goyim'),
            ('afrit', 'afriti'),
        ):
            self.assertEqual(p._plnoun(sing), plur)

        # p.classical(0)
        # p.classical('names')
        # clasical now back to the default mode

    def test_classical_pl(self):
        p = inflect.engine()
        p.classical()
        for sing, plur in (
            ('brother', 'brethren'),
            ('dogma', 'dogmata'),
        ):
            self.assertEqual(p.plural(sing), plur)

    def test__pl_special_verb(self):
        p = inflect.engine()
        self.assertEqual(p._pl_special_verb(''), False)
        self.assertEqual(p._pl_special_verb('am'), 'are')
        self.assertEqual(p._pl_special_verb('am', 0), 'are')
        self.assertEqual(p._pl_special_verb('runs', 0), 'run')
        p.classical(zero=True)
        self.assertEqual(p._pl_special_verb('am', 0), False)
        self.assertEqual(p._pl_special_verb('am', 1), 'am')
        self.assertEqual(p._pl_special_verb('am', 2), 'are')
        self.assertEqual(p._pl_special_verb('runs', 0), False)
        self.assertEqual(p._pl_special_verb('am going to'), 'are going to')
        self.assertEqual(p._pl_special_verb('did'), 'did')
        self.assertEqual(p._pl_special_verb("wasn't"), "weren't")
        self.assertEqual(p._pl_special_verb("shouldn't"), "shouldn't")
        self.assertEqual(p._pl_special_verb('bias'), False)
        self.assertEqual(p._pl_special_verb('news'), False)
        self.assertEqual(p._pl_special_verb('Jess'), False)
        self.assertEqual(p._pl_special_verb(' '), False)
        self.assertEqual(p._pl_special_verb('brushes'), 'brush')
        self.assertEqual(p._pl_special_verb('fixes'), 'fix')
        self.assertEqual(p._pl_special_verb('quizzes'), 'quiz')
        self.assertEqual(p._pl_special_verb('fizzes'), 'fizz')
        self.assertEqual(p._pl_special_verb('dresses'), 'dress')
        self.assertEqual(p._pl_special_verb('flies'), 'fly')
        self.assertEqual(p._pl_special_verb('canoes'), 'canoe')
        self.assertEqual(p._pl_special_verb('horseshoes'), 'horseshoe')
        self.assertEqual(p._pl_special_verb('does'), 'do')
        self.assertEqual(p._pl_special_verb('zzzoes'), 'zzzo')  # TODO: what's a real word to test this case?
        self.assertEqual(p._pl_special_verb('runs'), 'run')

    def test__pl_general_verb(self):
        p = inflect.engine()
        self.assertEqual(p._pl_general_verb('acts'), 'act')
        self.assertEqual(p._pl_general_verb('act'), 'act')
        self.assertEqual(p._pl_general_verb('saw'), 'saw')
        self.assertEqual(p._pl_general_verb('runs', 1), 'runs')

    def test__pl_special_adjective(self):
        p = inflect.engine()
        self.assertEqual(p._pl_special_adjective('a'), 'some')
        self.assertEqual(p._pl_special_adjective('my'), 'our')
        self.assertEqual(p._pl_special_adjective("John's"), "Johns'")
        # TODO: original can't handle this. should we handle it?
        self.TODO(p._pl_special_adjective("JOHN's"), "JOHNS'")
        # TODO: can't handle capitals
        self.TODO(p._pl_special_adjective("JOHN'S"), "JOHNS'")
        self.TODO(p._pl_special_adjective("TUNA'S"), "TUNA'S")
        self.assertEqual(p._pl_special_adjective("tuna's"), "tuna's")
        self.assertEqual(p._pl_special_adjective("TUNA's"), "TUNA's")
        self.assertEqual(p._pl_special_adjective("bad"), False)

    def test_a(self):
        p = inflect.engine()
        for sing, plur in (
            ('cat', 'a cat'),
            ('euphemism', 'a euphemism'),
            ('Euler number', 'an Euler number'),
            ('hour', 'an hour'),
            ('houri', 'a houri'),
            ('nth', 'an nth'),
            ('rth', 'an rth'),
            ('sth', 'an sth'),
            ('xth', 'an xth'),
            ('ant', 'an ant'),
            ('book', 'a book'),
            ('RSPCA', 'an RSPCA'),
            ('SONAR', 'a SONAR'),
            ('FJO', 'a FJO'),
            ('FJ', 'an FJ'),
            ('NASA', 'a NASA'),
            ('UN', 'a UN'),
            ('yak', 'a yak'),
            ('yttrium', 'an yttrium'),
            ('a elephant', 'an elephant'),
            ('a giraffe', 'a giraffe'),
            ('an ewe', 'a ewe'),
            ('a orangutan', 'an orangutan'),
            ('R.I.P.', 'an R.I.P.'),
            ('C.O.D.', 'a C.O.D.'),
            ('e-mail', 'an e-mail'),
            ('X-ray', 'an X-ray'),
            ('T-square', 'a T-square'),
            ('LCD', 'an LCD'),
            ('XML', 'an XML'),
            ('YWCA', 'a YWCA'),
            ('LED', 'a LED'),
            ('OPEC', 'an OPEC'),
            ('FAQ', 'a FAQ'),
            ('UNESCO', 'a UNESCO'),
            ('a', 'an a'),
            ('an', 'an an'),
            ('an ant', 'an ant'),
            ('a cat', 'a cat'),
            ('an cat', 'a cat'),
            ('a ant', 'an ant'),
        ):
            self.assertEqual(p.a(sing), plur)

        self.assertEqual(p.a('cat', 1), 'a cat')
        self.assertEqual(p.a('cat', 2), '2 cat')

        self.assertEqual(p.a, p.an)

    def test_no(self):
        p = inflect.engine()
        self.assertEqual(p.no('cat'), 'no cats')
        self.assertEqual(p.no('cat', count=3), '3 cats')
        self.assertEqual(p.no('cat', count='three'), 'three cats')
        self.assertEqual(p.no('cat', count=1), '1 cat')
        self.assertEqual(p.no('cat', count='one'), 'one cat')
        self.assertEqual(p.no('mouse'), 'no mice')
        p.num(3)
        self.assertEqual(p.no('cat'), '3 cats')

    def test_prespart(self):
        p = inflect.engine()
        for sing, plur in (
            ('runs', 'running'),
            ('dies', 'dying'),
            ('glues', 'gluing'),
            ('eyes', 'eying'),
            ('skis', 'skiing'),
            ('names', 'naming'),
            ('sees', 'seeing'),
            ('hammers', 'hammering'),
            ('bats', 'batting'),
            ('eats', 'eating'),
            ('loves', 'loving'),
            ('spies', 'spying'),
        ):
            self.assertEqual(p.present_participle(sing), plur)

        self.assertEqual(p.present_participle('hoes'), 'hoeing')
        self.assertEqual(p.present_participle('alibis'), 'alibiing')
        self.assertEqual(p.present_participle('is'), 'being')
        self.assertEqual(p.present_participle('are'), 'being')
        self.assertEqual(p.present_participle('had'), 'having')
        self.assertEqual(p.present_participle('has'), 'having')

    def test_ordinal(self):
        p = inflect.engine()
        for num, numord in (
            ('1', '1st'),
            ('2', '2nd'),
            ('3', '3rd'),
            ('4', '4th'),
            ('10', '10th'),
            ('28', '28th'),
            ('100', '100th'),
            ('101', '101st'),
            ('1000', '1000th'),
            ('1001', '1001st'),
            ('0', '0th'),
            ('one', 'first'),
            ('two', 'second'),
            ('four', 'fourth'),
            ('twenty', 'twentieth'),
            ('one hundered', 'one hunderedth'),
            ('one hundered and one', 'one hundered and first'),
            ('zero', 'zeroth'),
            ('n', 'nth'),  # bonus!
        ):
            self.assertEqual(p.ordinal(num), numord)

    def test_millfn(self):
        p = inflect.engine()
        millfn = p.millfn
        self.assertEqual(millfn(1), ' thousand')
        self.assertEqual(millfn(2), ' million')
        self.assertEqual(millfn(3), ' billion')
        self.assertEqual(millfn(0), ' ')
        self.assertEqual(millfn(11), ' decillion')
        inflect.STDOUT_ON = False
        self.assertRaises(NumOutOfRangeError, millfn, 12)
        inflect.STDOUT_ON = True

    def test_unitfn(self):
        p = inflect.engine()
        unitfn = p.unitfn
        self.assertEqual(unitfn(1, 2), 'one million')
        self.assertEqual(unitfn(1, 3), 'one billion')
        self.assertEqual(unitfn(5, 3), 'five billion')
        self.assertEqual(unitfn(5, 0), 'five ')
        self.assertEqual(unitfn(0, 0), ' ')

    def test_tenfn(self):
        p = inflect.engine()
        tenfn = p.tenfn
        self.assertEqual(tenfn(3, 1, 2), 'thirty-one million')
        self.assertEqual(tenfn(3, 0, 2), 'thirty million')
        self.assertEqual(tenfn(0, 1, 2), 'one million')
        self.assertEqual(tenfn(1, 1, 2), 'eleven million')
        self.assertEqual(tenfn(1, 0, 2), 'ten million')
        self.assertEqual(tenfn(1, 0, 0), 'ten ')
        self.assertEqual(tenfn(0, 0, 0), ' ')

    def test_hundfn(self):
        p = inflect.engine()
        hundfn = p.hundfn
        p.number_args = dict(andword='and')
        self.assertEqual(hundfn(4, 3, 1, 2), 'four hundred and thirty-one  million, ')
        self.assertEqual(hundfn(4, 0, 0, 2), 'four hundred  million, ')
        self.assertEqual(hundfn(4, 0, 5, 2), 'four hundred and five  million, ')
        self.assertEqual(hundfn(0, 3, 1, 2), 'thirty-one  million, ')
        self.assertEqual(hundfn(0, 0, 7, 2), 'seven  million, ')

    def test_enword(self):
        p = inflect.engine()
        enword = p.enword
        self.assertEqual(enword('5', 1),
                         'five, ')
        p.number_args = dict(zero='zero', one='one', andword='and')
        self.assertEqual(enword('0', 1),
                         ' zero, ')
        self.assertEqual(enword('1', 1),
                         ' one, ')
        self.assertEqual(enword('347', 1),
                         'three, four, seven, ')

        self.assertEqual(enword('34', 2),
                         'thirty-four , ')
        self.assertEqual(enword('347', 2),
                         'thirty-four , seven, ')
        self.assertEqual(enword('34768', 2),
                         'thirty-four , seventy-six , eight, ')
        self.assertEqual(enword('1', 2),
                         'one, ')
        p.number_args['one'] = 'single'
        self.TODO(enword('1', 2),
                  'single, ', 'one, ')  # TODO: doesn't use default word for 'one' here

        p.number_args['one'] = 'one'

        self.assertEqual(enword('134', 3),
                         ' one thirty-four , ')

        self.assertEqual(enword('0', -1),
                         'zero')
        self.assertEqual(enword('1', -1),
                         'one')

        self.assertEqual(enword('3', -1),
                         'three , ')
        self.assertEqual(enword('12', -1),
                         'twelve , ')
        self.assertEqual(enword('123', -1),
                         'one hundred and twenty-three  , ')
        self.assertEqual(enword('1234', -1),
                         'one thousand, two hundred and thirty-four  , ')
        self.assertEqual(enword('12345', -1),
                         'twelve thousand, three hundred and forty-five  , ')
        self.assertEqual(enword('123456', -1),
                         'one hundred and twenty-three  thousand, four hundred and fifty-six  , ')
        self.assertEqual(enword('1234567', -1),
                         'one million, two hundred and thirty-four  thousand, five hundred and sixty-seven  , ')

    def test_numwords(self):
        p = inflect.engine()
        numwords = p.number_to_words

        for n, word in (
            ('1', 'one'),
            ('10', 'ten'),
            ('100', 'one hundred'),
            ('1000', 'one thousand'),
            ('10000', 'ten thousand'),
            ('100000', 'one hundred thousand'),
            ('1000000', 'one million'),
            ('10000000', 'ten million'),
            ('+10', 'plus ten'),
            ('-10', 'minus ten'),
            ('10.', 'ten point'),
            ('.10', 'point one zero'),
        ):
            self.assertEqual(numwords(n), word)

        for n, word, wrongword in (
            # TODO: should be one point two three
            ('1.23', 'one point two three', 'one point twenty-three'),
        ):
            self.assertEqual(numwords(n), word)

        for n, txt in (
            (3, 'three bottles of beer on the wall'),
            (2, 'two bottles of beer on the wall'),
            (1, 'a solitary bottle of beer on the wall'),
            (0, 'no more bottles of beer on the wall'),
        ):
            self.assertEqual("%s%s" % (
                numwords(n, one='a solitary', zero='no more'),
                p.plural(" bottle of beer on the wall", n)),
                txt)

        self.assertEqual(numwords(0, one='one', zero='zero'), 'zero')

        self.assertEqual(numwords('1234'),
                         'one thousand, two hundred and thirty-four')
        self.assertEqual(numwords('1234', wantlist=True),
                         ['one thousand', 'two hundred and thirty-four'])
        self.assertEqual(numwords('1234567', wantlist=True),
                         ['one million',
                          'two hundred and thirty-four thousand',
                          'five hundred and sixty-seven'])
        self.assertEqual(numwords('+10', wantlist=True),
                         ['plus', 'ten'])
        self.assertEqual(numwords('1234', andword=''),
                         'one thousand, two hundred thirty-four')
        self.assertEqual(numwords('1234', andword='plus'),
                         'one thousand, two hundred plus thirty-four')
        self.assertEqual(numwords(p.ordinal('21')),
                         'twenty-first')
        self.assertEqual(numwords('9', threshold=10),
                         'nine')
        self.assertEqual(numwords('10', threshold=10),
                         'ten')
        self.assertEqual(numwords('11', threshold=10),
                         '11')
        self.assertEqual(numwords('1000', threshold=10),
                         '1,000')
        self.assertEqual(numwords('123', threshold=10),
                         '123')
        self.assertEqual(numwords('1234', threshold=10),
                         '1,234')
        self.assertEqual(numwords('1234.5678', threshold=10),
                         '1,234.5678')
        self.assertEqual(numwords('1', decimal=None),
                         'one')
        self.assertEqual(numwords('1234.5678', decimal=None),
                         'twelve million, three hundred and forty-five thousand, six hundred and seventy-eight')

    def test_numwords_group(self):
        p = inflect.engine()
        numwords = p.number_to_words
        self.assertEqual(numwords('12345', group=2),
                         'twelve, thirty-four, five')
        # TODO: 'hundred and' missing
        self.TODO(numwords('12345', group=3),
                  'one hundred and twenty-three',
                  'one twenty-three, forty-five')
        self.assertEqual(numwords('123456', group=3),
                         'one twenty-three, four fifty-six')
        self.assertEqual(numwords('12345', group=1),
                         'one, two, three, four, five')
        self.assertEqual(numwords('1234th', group=0, andword='and'),
                         'one thousand, two hundred and thirty-fourth')
        self.assertEqual(numwords(p.ordinal('1234'), group=0),
                         'one thousand, two hundred and thirty-fourth')
        self.assertEqual(numwords('120', group=2),
                         'twelve, zero')
        self.assertEqual(numwords('120', group=2, zero='oh', one='unity'),
                         'twelve, oh')
        # TODO: ignoring 'one' param with group=2
        self.TODO(numwords('101', group=2, zero='oh', one='unity'),
                  'ten, unity',
                  'ten, one')
        self.assertEqual(numwords('555_1202', group=1, zero='oh'),
                         'five, five, five, one, two, oh, two')
        self.assertEqual(numwords('555_1202', group=1, one='unity'),
                         'five, five, five, unity, two, zero, two')
        self.assertEqual(numwords('123.456', group=1, decimal='mark', one='one'),
                         'one, two, three, mark, four, five, six')

        inflect.STDOUT_ON = False
        self.assertRaises(BadChunkingOptionError,
                          numwords, '1234', group=4)
        inflect.STDOUT_ON = True

    def test_wordlist(self):
        p = inflect.engine()
        wordlist = p.join
        self.assertEqual(wordlist([]),
                         '')
        self.assertEqual(wordlist(('apple',)),
                         'apple')
        self.assertEqual(wordlist(('apple', 'banana')),
                         'apple and banana')
        self.assertEqual(wordlist(('apple', 'banana', 'carrot')),
                         'apple, banana, and carrot')
        self.assertEqual(wordlist(('apple', '1,000', 'carrot')),
                         'apple; 1,000; and carrot')
        self.assertEqual(wordlist(('apple', '1,000', 'carrot'), sep=','),
                         'apple, 1,000, and carrot')
        self.assertEqual(wordlist(('apple', 'banana', 'carrot'), final_sep=""),
                         'apple, banana and carrot')
        self.assertEqual(wordlist(('apple', 'banana', 'carrot'), final_sep=";"),
                         'apple, banana; and carrot')
        self.assertEqual(wordlist(('apple', 'banana', 'carrot'), conj="or"),
                         'apple, banana, or carrot')

        self.assertEqual(wordlist(('apple', 'banana'), conj=" or "),
                         'apple  or  banana')
        self.assertEqual(wordlist(('apple', 'banana'), conj="&"),
                         'apple & banana')  # TODO: want spaces here. Done, report upstream
        self.assertEqual(wordlist(('apple', 'banana'), conj="&", conj_spaced=False),
                         'apple&banana')
        self.assertEqual(wordlist(('apple', 'banana'), conj="& ", conj_spaced=False),
                         'apple& banana')

        self.assertEqual(wordlist(('apple', 'banana', 'carrot'), conj=" or "),
                         'apple, banana,  or  carrot')
        self.assertEqual(wordlist(('apple', 'banana', 'carrot'), conj="+"),
                         'apple, banana, + carrot')
        self.assertEqual(wordlist(('apple', 'banana', 'carrot'), conj="&"),
                         'apple, banana, & carrot')  # TODO: want space here. Done, report updtream
        self.assertEqual(wordlist(('apple', 'banana', 'carrot'), conj="&", conj_spaced=False),
                         'apple, banana,&carrot')  # TODO: want space here. Done, report updtream
        self.assertEqual(wordlist(('apple', 'banana', 'carrot'), conj=" &", conj_spaced=False),
                         'apple, banana, &carrot')  # TODO: want space here. Done, report updtream

    def test_print(self):
        inflect.STDOUT_ON = True
        inflect.print3('')  # make sure it doesn't crash
        inflect.STDOUT_ON = False

    def test_doc_examples(self):
        p = inflect.engine()
        self.assertEqual(p.plural_noun('I'), 'we')
        self.assertEqual(p.plural_verb('saw'), 'saw')
        self.assertEqual(p.plural_adj('my'), 'our')
        self.assertEqual(p.plural_noun('saw'), 'saws')
        self.assertEqual(p.plural('was'), 'were')
        self.assertEqual(p.plural('was', 1), 'was')
        self.assertEqual(p.plural_verb('was', 2), 'were')
        self.assertEqual(p.plural_verb('was'), 'were')
        self.assertEqual(p.plural_verb('was', 1), 'was')

        for errors, txt in (
            (0, 'There were no errors'),
            (1, 'There was 1 error'),
            (2, 'There were 2 errors'),
        ):
            self.assertEqual("There %s%s" % (p.plural_verb('was', errors), p.no(" error", errors)),
                             txt)

            self.assertEqual(p.inflect("There plural_verb(was,%d) no(error,%d)" % (errors, errors)),
                             txt)

        for num1, num2, txt in (
            (1, 2, 'I saw 2 saws'),
            (2, 1, 'we saw 1 saw'),
        ):
            self.assertEqual("%s%s%s %s%s" % (
                p.num(num1, ""),
                p.plural("I"),
                p.plural_verb(" saw"),
                p.num(num2),
                p.plural_noun(" saw")),
                txt)

            self.assertEqual(
                p.inflect(
                    'num(%d,)plural(I) plural_verb(saw) num(%d) plural_noun(saw)' % (num1, num2)
                ), txt)

        self.assertEqual(p.a('a cat'), 'a cat')

        for word, txt in (
            ('cat', 'a cat'),
            ('aardvark', 'an aardvark'),
            ('ewe', 'a ewe'),
            ('hour', 'an hour'),
        ):
            self.assertEqual(p.a('%s %s' % (p.number_to_words(1, one='a'), word)), txt)

        p.num(2)

    def test_deprecation(self):
        p = inflect.engine()
        for meth in ('pl',
                     'plnoun',
                     'plverb',
                     'pladj',
                     'sinoun',
                     'prespart',
                     'numwords',
                     'plequal',
                     'plnounequal',
                     'plverbequal',
                     'pladjequal',
                     'wordlist',
                     ):
            self.assertRaises(DeprecationWarning, getattr, p, meth)


# TODO: test .inflectrc file code

if __name__ == "__main__":
    try:
        unittest.main()
    except SystemExit:
        pass



import unittest

import inflect


class test(unittest.TestCase):
    def test_classical(self):
        p = inflect.engine()

        # DEFAULT...

        self.assertEqual(p.plural_noun('error', 0),   'errors',      msg="classical 'zero' not active")
        self.assertEqual(p.plural_noun('wildebeest'), 'wildebeests', msg="classical 'herd' not active")
        self.assertEqual(p.plural_noun('Sally'),      'Sallys',      msg="classical 'names' active")
        self.assertEqual(p.plural_noun('brother'),    'brothers',    msg="classical others not active")
        self.assertEqual(p.plural_noun('person'),     'people',      msg="classical 'persons' not active")
        self.assertEqual(p.plural_noun('formula'),    'formulas',    msg="classical 'ancient' not active")

        # CLASSICAL PLURALS ACTIVATED...

        p.classical(all=True)
        self.assertEqual(p.plural_noun('error', 0),   'error',       msg="classical 'zero' active")
        self.assertEqual(p.plural_noun('wildebeest'), 'wildebeest',  msg="classical 'herd' active")
        self.assertEqual(p.plural_noun('Sally'),      'Sallys',      msg="classical 'names' active")
        self.assertEqual(p.plural_noun('brother'),    'brethren',    msg="classical others active")
        self.assertEqual(p.plural_noun('person'),     'persons',     msg="classical 'persons' active")
        self.assertEqual(p.plural_noun('formula'),    'formulae',    msg="classical 'ancient' active")

        # CLASSICAL PLURALS DEACTIVATED...

        p.classical(all=False)
        self.assertEqual(p.plural_noun('error', 0),   'errors',      msg="classical 'zero' not active")
        self.assertEqual(p.plural_noun('wildebeest'), 'wildebeests', msg="classical 'herd' not active")
        self.assertEqual(p.plural_noun('Sally'),      'Sallies',     msg="classical 'names' not active")
        self.assertEqual(p.plural_noun('brother'),    'brothers',    msg="classical others not active")
        self.assertEqual(p.plural_noun('person'),     'people',      msg="classical 'persons' not active")
        self.assertEqual(p.plural_noun('formula'),    'formulas',    msg="classical 'ancient' not active")

        # CLASSICAL PLURALS REREREACTIVATED...

        p.classical()
        self.assertEqual(p.plural_noun('error', 0),   'error',       msg="classical 'zero' active")
        self.assertEqual(p.plural_noun('wildebeest'), 'wildebeest',  msg="classical 'herd' active")
        self.assertEqual(p.plural_noun('Sally'),      'Sallys',      msg="classical 'names' active")
        self.assertEqual(p.plural_noun('brother'),    'brethren',    msg="classical others active")
        self.assertEqual(p.plural_noun('person'),     'persons',     msg="classical 'persons' active")
        self.assertEqual(p.plural_noun('formula'),    'formulae',    msg="classical 'ancient' active")

if __name__ == '__main__':
    try:
        unittest.main()
    except SystemExit:
        pass




from nose.tools import eq_, assert_not_equal

import inflect


def is_eq(p, a, b):
    return (p.compare(a, b) or
            p.plnounequal(a, b) or
            p.plverbequal(a, b) or
            p.pladjequal(a, b))


def test_many():
    p = inflect.engine()

    data = get_data()

    for line in data:
        if 'TODO:' in line:
            continue
        try:
            singular, rest = line.split('->', 1)
        except ValueError:
            continue
        singular = singular.strip()
        rest = rest.strip()
        try:
            plural, comment = rest.split('#', 1)
        except ValueError:
            plural = rest.strip()
            comment = ''
        try:
            mod_plural, class_plural = plural.split("|", 1)
            mod_plural = mod_plural.strip()
            class_plural = class_plural.strip()
        except ValueError:
            mod_plural = class_plural = plural.strip()
        if 'verb' in comment.lower():
            is_nv = '_V'
        elif 'noun' in comment.lower():
            is_nv = '_N'
        else:
            is_nv = ''

        p.classical(all=0, names=0)
        mod_PL_V = p.plural_verb(singular)
        mod_PL_N = p.plural_noun(singular)
        mod_PL = p.plural(singular)
        if is_nv == '_V':
            mod_PL_val = mod_PL_V
        elif is_nv == '_N':
            mod_PL_val = mod_PL_N
        else:
            mod_PL_val = mod_PL

        p.classical(all=1)
        class_PL_V = p.plural_verb(singular)
        class_PL_N = p.plural_noun(singular)
        class_PL = p.plural(singular)
        if is_nv == '_V':
            class_PL_val = class_PL_V
        elif is_nv == '_N':
            class_PL_val = class_PL_N
        else:
            class_PL_val = class_PL

        yield check_all, p, is_nv, singular, mod_PL_val, class_PL_val, mod_plural, class_plural


def check_all(p, is_nv, singular, mod_PL_val, class_PL_val, mod_plural, class_plural):
    eq_(mod_plural, mod_PL_val)
    eq_(class_plural, class_PL_val)
    eq_(is_eq(p, singular, mod_plural) in ('s:p', 'p:s', 'eq'), True,
        msg='is_eq(%s,%s) == %s != %s' % (singular, mod_plural, is_eq(p, singular, mod_plural), 's:p, p:s or eq'))
    eq_(is_eq(p, mod_plural, singular) in ('p:s', 's:p', 'eq'), True,
        msg='is_eq(%s,%s) == %s != %s' % (mod_plural, singular, is_eq(p, mod_plural, singular), 's:p, p:s or eq'))
    eq_(is_eq(p, singular, class_plural) in ('s:p', 'p:s', 'eq'), True)
    eq_(is_eq(p, class_plural, singular) in ('p:s', 's:p', 'eq'), True)
    assert_not_equal(singular, '')
    eq_(mod_PL_val, mod_PL_val if class_PL_val else '%s|%s' (mod_PL_val, class_PL_val))

    if is_nv != '_V':
        eq_(p.singular_noun(mod_plural, 1), singular,
            msg="p.singular_noun(%s) == %s != %s" % (mod_plural, p.singular_noun(mod_plural, 1), singular))

        eq_(p.singular_noun(class_plural, 1), singular,
            msg="p.singular_noun(%s) == %s != %s" % (class_plural, p.singular_noun(class_plural, 1), singular))

    '''
    don't see any test data for this ???
    elsif (/^\s+(an?)\s+(.*?)\s*$/)
    {
        $article = $1
        $word    = $2
        $Aword   = A($word)

        ok ("$article $word" eq $Aword, "$article $word")
    }
    '''


def test_def():
    p = inflect.engine()

    p.defnoun("kin", "kine")
    p.defnoun('(.*)x', '$1xen')

    p.defverb('foobar',  'feebar',
              'foobar',  'feebar',
              'foobars', 'feebar')

    p.defadj('red', 'red|gules')

    eq_(p.no("kin", 0), "no kine", msg="kin -> kine (user defined)...")
    eq_(p.no("kin", 1), "1 kin")
    eq_(p.no("kin", 2), "2 kine")

    eq_(p.no("regex", 0), "no regexen", msg="regex -> regexen (user defined)")

    eq_(p.plural("foobar", 2), "feebar", msg="foobar -> feebar (user defined)...")
    eq_(p.plural("foobars", 2), "feebar")

    eq_(p.plural("red", 0), "red", msg="red -> red...")
    eq_(p.plural("red", 1), "red")
    eq_(p.plural("red", 2), "red")
    p.classical(all=True)
    eq_(p.plural("red", 0), "red", msg="red -> gules...")
    eq_(p.plural("red", 1), "red")
    eq_(p.plural("red", 2), "gules")


def test_ordinal():
    p = inflect.engine()
    eq_(p.ordinal(0), "0th", msg="0 -> 0th...")
    eq_(p.ordinal(1), "1st")
    eq_(p.ordinal(2), "2nd")
    eq_(p.ordinal(3), "3rd")
    eq_(p.ordinal(4), "4th")
    eq_(p.ordinal(5), "5th")
    eq_(p.ordinal(6), "6th")
    eq_(p.ordinal(7), "7th")
    eq_(p.ordinal(8), "8th")
    eq_(p.ordinal(9), "9th")
    eq_(p.ordinal(10), "10th")
    eq_(p.ordinal(11), "11th")
    eq_(p.ordinal(12), "12th")
    eq_(p.ordinal(13), "13th")
    eq_(p.ordinal(14), "14th")
    eq_(p.ordinal(15), "15th")
    eq_(p.ordinal(16), "16th")
    eq_(p.ordinal(17), "17th")
    eq_(p.ordinal(18), "18th")
    eq_(p.ordinal(19), "19th")
    eq_(p.ordinal(20), "20th")
    eq_(p.ordinal(21), "21st")
    eq_(p.ordinal(22), "22nd")
    eq_(p.ordinal(23), "23rd")
    eq_(p.ordinal(24), "24th")
    eq_(p.ordinal(100), "100th")
    eq_(p.ordinal(101), "101st")
    eq_(p.ordinal(102), "102nd")
    eq_(p.ordinal(103), "103rd")
    eq_(p.ordinal(104), "104th")

    eq_(p.ordinal('zero'), "zeroth", msg="zero -> zeroth...")
    eq_(p.ordinal('one'), "first")
    eq_(p.ordinal('two'), "second")
    eq_(p.ordinal('three'), "third")
    eq_(p.ordinal('four'), "fourth")
    eq_(p.ordinal('five'), "fifth")
    eq_(p.ordinal('six'), "sixth")
    eq_(p.ordinal('seven'), "seventh")
    eq_(p.ordinal('eight'), "eighth")
    eq_(p.ordinal('nine'), "ninth")
    eq_(p.ordinal('ten'), "tenth")
    eq_(p.ordinal('eleven'), "eleventh")
    eq_(p.ordinal('twelve'), "twelfth")
    eq_(p.ordinal('thirteen'), "thirteenth")
    eq_(p.ordinal('fourteen'), "fourteenth")
    eq_(p.ordinal('fifteen'), "fifteenth")
    eq_(p.ordinal('sixteen'), "sixteenth")
    eq_(p.ordinal('seventeen'), "seventeenth")
    eq_(p.ordinal('eighteen'), "eighteenth")
    eq_(p.ordinal('nineteen'), "nineteenth")
    eq_(p.ordinal('twenty'), "twentieth")
    eq_(p.ordinal('twenty-one'), "twenty-first")
    eq_(p.ordinal('twenty-two'), "twenty-second")
    eq_(p.ordinal('twenty-three'), "twenty-third")
    eq_(p.ordinal('twenty-four'), "twenty-fourth")
    eq_(p.ordinal('one hundred'), "one hundredth")
    eq_(p.ordinal('one hundred and one'), "one hundred and first")
    eq_(p.ordinal('one hundred and two'), "one hundred and second")
    eq_(p.ordinal('one hundred and three'), "one hundred and third")
    eq_(p.ordinal('one hundred and four'), "one hundred and fourth")


def test_prespart():
    p = inflect.engine()
    eq_(p.present_participle("sees"), "seeing", msg="sees -> seeing...")
    eq_(p.present_participle("eats"), "eating")
    eq_(p.present_participle("bats"), "batting")
    eq_(p.present_participle("hates"), "hating")
    eq_(p.present_participle("spies"), "spying")
    eq_(p.present_participle("skis"), "skiing")


def get_data():
    return '''
                    a  ->  as                             # NOUN FORM
      TODO:sing              a  ->  some                           # INDEFINITE ARTICLE
      TODO:  A.C.R.O.N.Y.M.  ->  A.C.R.O.N.Y.M.s
             abscissa  ->  abscissas|abscissae
             Achinese  ->  Achinese
            acropolis  ->  acropolises
                adieu  ->  adieus|adieux
     adjutant general  ->  adjutant generals
                aegis  ->  aegises
             afflatus  ->  afflatuses
               afreet  ->  afreets|afreeti
                afrit  ->  afrits|afriti
              agendum  ->  agenda
         aide-de-camp  ->  aides-de-camp
             Alabaman  ->  Alabamans
               albino  ->  albinos
                album  ->  albums
             Alfurese  ->  Alfurese
                 alga  ->  algae
                alias  ->  aliases
                 alto  ->  altos|alti
               alumna  ->  alumnae
              alumnus  ->  alumni
             alveolus  ->  alveoli
   TODO:siverb                am  ->  are
   TODO:siverb          am going  ->  are going
  ambassador-at-large  ->  ambassadors-at-large
            Amboinese  ->  Amboinese
          Americanese  ->  Americanese
               amoeba  ->  amoebas|amoebae
              Amoyese  ->  Amoyese
   TODO:siadj                an  ->  some                           # INDEFINITE ARTICLE
             analysis  ->  analyses
             anathema  ->  anathemas|anathemata
           Andamanese  ->  Andamanese
             Angolese  ->  Angolese
             Annamese  ->  Annamese
              antenna  ->  antennas|antennae
                 anus  ->  anuses
                 apex  ->  apexes|apices
   TODO:siadj            apex's  ->  apexes'|apices'                # POSSESSIVE FORM
             aphelion  ->  aphelia
            apparatus  ->  apparatuses|apparatus
             appendix  ->  appendixes|appendices
                apple  ->  apples
             aquarium  ->  aquariums|aquaria
            Aragonese  ->  Aragonese
            Arakanese  ->  Arakanese
          archipelago  ->  archipelagos
   TODO:siverb               are  ->  are
   TODO:siverb          are made  ->  are made
            armadillo  ->  armadillos
             arpeggio  ->  arpeggios
            arthritis  ->  arthritises|arthritides
             asbestos  ->  asbestoses
            asparagus  ->  asparaguses
                  ass  ->  asses
             Assamese  ->  Assamese
               asylum  ->  asylums
            asyndeton  ->  asyndeta
                at it  ->  at them                        # ACCUSATIVE
               ataman  ->  atamans
   TODO:siverb               ate  ->  ate
                atlas  ->  atlases|atlantes
                atman  ->  atmas
  TODO:singular_noun   attorney general  ->  attorneys general
   attorney of record  ->  attorneys of record
               aurora  ->  auroras|aurorae
                 auto  ->  autos
           auto-da-fe  ->  autos-da-fe
             aviatrix  ->  aviatrixes|aviatrices
    TODO:siadj       aviatrix's  ->  aviatrixes'|aviatrices'
           Avignonese  ->  Avignonese
                  axe  ->  axes
    TODO:singular_noun 2 anwers!            axis  ->  axes
                axman  ->  axmen
        Azerbaijanese  ->  Azerbaijanese
             bacillus  ->  bacilli
            bacterium  ->  bacteria
              Bahaman  ->  Bahamans
             Balinese  ->  Balinese
               bamboo  ->  bamboos
                banjo  ->  banjoes
                 bass  ->  basses                         # INSTRUMENT, NOT FISH
                basso  ->  bassos|bassi
               bathos  ->  bathoses
                 beau  ->  beaus|beaux
                 beef  ->  beefs|beeves
           beneath it  ->  beneath them                   # ACCUSATIVE
            Bengalese  ->  Bengalese
                 bent  ->  bent                           # VERB FORM
                 bent  ->  bents                          # NOUN FORM
              Bernese  ->  Bernese
            Bhutanese  ->  Bhutanese
                 bias  ->  biases
               biceps  ->  biceps
                bison  ->  bisons|bison
               blouse  ->  blouses
            Bolognese  ->  Bolognese
                bonus  ->  bonuses
             Borghese  ->  Borghese
                 boss  ->  bosses
            Bostonese  ->  Bostonese
                  box  ->  boxes
                  boy  ->  boys
                bravo  ->  bravoes
                bream  ->  bream
             breeches  ->  breeches
          bride-to-be  ->  brides-to-be
    Brigadier General  ->  Brigadier Generals
             britches  ->  britches
           bronchitis  ->  bronchitises|bronchitides
             bronchus  ->  bronchi
              brother  ->  brothers|brethren
   TODO:         brother's  ->  brothers'|brethren's
              buffalo  ->  buffaloes|buffalo
             Buginese  ->  Buginese
                 buoy  ->  buoys
               bureau  ->  bureaus|bureaux
               Burman  ->  Burmans
              Burmese  ->  Burmese
             bursitis  ->  bursitises|bursitides
                  bus  ->  buses
                 buzz  ->  buzzes
               buzzes  ->  buzz                           # VERB FORM
                by it  ->  by them                        # ACCUSATIVE
               caddis  ->  caddises
               caiman  ->  caimans
                 cake  ->  cakes
            Calabrese  ->  Calabrese
                 calf  ->  calves
               callus  ->  calluses
          Camaldolese  ->  Camaldolese
                cameo  ->  cameos
               campus  ->  campuses
                  can  ->  cans                           # NOUN FORM
                  can  ->  can                            # VERB FORM (all pers.)
                can't  ->  can't                          # VERB FORM
          candelabrum  ->  candelabra
             cannabis  ->  cannabises
      TODO:siverb         canoes  ->  canoe
                canto  ->  cantos
            Cantonese  ->  Cantonese
               cantus  ->  cantus
               canvas  ->  canvases
              CAPITAL  ->  CAPITALS
            carcinoma  ->  carcinomas|carcinomata
                 care  ->  cares
                cargo  ->  cargoes
              caribou  ->  caribous|caribou
            Carlylese  ->  Carlylese
               carmen  ->  carmina
                 carp  ->  carp
            Cassinese  ->  Cassinese
                  cat  ->  cats
              catfish  ->  catfish
               cayman  ->  caymans
             Celanese  ->  Celanese
              ceriman  ->  cerimans
               cervid  ->  cervids
            Ceylonese  ->  Ceylonese
             chairman  ->  chairmen
              chamois  ->  chamois
                chaos  ->  chaoses
              chapeau  ->  chapeaus|chapeaux
             charisma  ->  charismas|charismata
    TODO:siverb           chases  ->  chase
              chassis  ->  chassis
              chateau  ->  chateaus|chateaux
               cherub  ->  cherubs|cherubim
           chickenpox  ->  chickenpox
                chief  ->  chiefs
                child  ->  children
              Chinese  ->  Chinese
               chorus  ->  choruses
            chrysalis  ->  chrysalises|chrysalides
               church  ->  churches
             cicatrix  ->  cicatrixes|cicatrices
               circus  ->  circuses
                class  ->  classes
              classes  ->  class                          # VERB FORM
             clippers  ->  clippers
             clitoris  ->  clitorises|clitorides
                  cod  ->  cod
                codex  ->  codices
               coitus  ->  coitus
             commando  ->  commandos
           compendium  ->  compendiums|compendia
                coney  ->  coneys
             Congoese  ->  Congoese
            Congolese  ->  Congolese
           conspectus  ->  conspectuses
            contralto  ->  contraltos|contralti
          contretemps  ->  contretemps
            conundrum  ->  conundrums
                corps  ->  corps
               corpus  ->  corpuses|corpora
               cortex  ->  cortexes|cortices
               cosmos  ->  cosmoses
     TODO:singular_noun   court martial  ->  courts martial
                  cow  ->  cows|kine
              cranium  ->  craniums|crania
            crescendo  ->  crescendos
            criterion  ->  criteria
           curriculum  ->  curriculums|curricula
                czech  ->  czechs
                 dais  ->  daises
           data point  ->  data points
                datum  ->  data
               debris  ->  debris
              decorum  ->  decorums
                 deer  ->  deer
           delphinium  ->  delphiniums
          desideratum  ->  desiderata
               desman  ->  desmans
             diabetes  ->  diabetes
               dictum  ->  dictums|dicta
    TODO:siverb              did  ->  did
    TODO:siverb         did need  ->  did need
            digitalis  ->  digitalises
                dingo  ->  dingoes
              diploma  ->  diplomas|diplomata
               discus  ->  discuses
                 dish  ->  dishes
                ditto  ->  dittos
                djinn  ->  djinn
     TODO:siverb            does  ->  do
     TODO:siverb         doesn't  ->  don't                          # VERB FORM
                  dog  ->  dogs
                dogma  ->  dogmas|dogmata
               dolman  ->  dolmans
           dominatrix  ->  dominatrixes|dominatrices
               domino  ->  dominoes
            Dongolese  ->  Dongolese
             dormouse  ->  dormice
                drama  ->  dramas|dramata
                 drum  ->  drums
                dwarf  ->  dwarves
               dynamo  ->  dynamos
                edema  ->  edemas|edemata
                eland  ->  elands|eland
                  elf  ->  elves
                  elk  ->  elks|elk
               embryo  ->  embryos
             emporium  ->  emporiums|emporia
         encephalitis  ->  encephalitises|encephalitides
             enconium  ->  enconiums|enconia
                enema  ->  enemas|enemata
               enigma  ->  enigmas|enigmata
            epidermis  ->  epidermises
           epididymis  ->  epididymises|epididymides
              erratum  ->  errata
                ethos  ->  ethoses
           eucalyptus  ->  eucalyptuses
               eunuch  ->  eunuchs
             extremum  ->  extrema
                 eyas  ->  eyases
             factotum  ->  factotums
               farman  ->  farmans
              Faroese  ->  Faroese
                fauna  ->  faunas|faunae
                  fax  ->  faxes
            Ferrarese  ->  Ferrarese
                ferry  ->  ferries
                fetus  ->  fetuses
               fiance  ->  fiances
              fiancee  ->  fiancees
               fiasco  ->  fiascos
                 fish  ->  fish
                 fizz  ->  fizzes
             flamingo  ->  flamingoes
         flittermouse  ->  flittermice
     TODO:siverb           floes  ->  floe
                flora  ->  floras|florae
             flounder  ->  flounder
                focus  ->  focuses|foci
               foetus  ->  foetuses
                folio  ->  folios
           Foochowese  ->  Foochowese
                 foot  ->  feet
     TODO:siadj          foot's  ->  feet's                         # POSSESSIVE FORM
              foramen  ->  foramens|foramina
     TODO:siverb       foreshoes  ->  foreshoe
              formula  ->  formulas|formulae
                forum  ->  forums
     TODO:siverb          fought  ->  fought
                  fox  ->  foxes
     TODO:singular_noun 2 different returns        from him  ->  from them
              from it  ->  from them                      # ACCUSATIVE
               fungus  ->  funguses|fungi
             Gabunese  ->  Gabunese
              gallows  ->  gallows
             ganglion  ->  ganglions|ganglia
                  gas  ->  gases
               gateau  ->  gateaus|gateaux
    TODO:siverb             gave  ->  gave
              general  ->  generals
        generalissimo  ->  generalissimos
             Genevese  ->  Genevese
                genie  ->  genies|genii
    TODO:singular_noun 2 diff return values!           genius  ->  geniuses|genii
              Genoese  ->  Genoese
                genus  ->  genera
               German  ->  Germans
               ghetto  ->  ghettos
           Gilbertese  ->  Gilbertese
              glottis  ->  glottises
              Goanese  ->  Goanese
                 goat  ->  goats
                goose  ->  geese
    TODO:singular_noun Governor General  ->  Governors General
                  goy  ->  goys|goyim
             graffiti  ->  graffiti
    TODO:singular_noun 2 diff ret values         graffito  ->  graffiti
              grizzly  ->  grizzlies
                guano  ->  guanos
            guardsman  ->  guardsmen
             Guianese  ->  Guianese
                gumma  ->  gummas|gummata
    TODO:siverb         gumshoes  ->  gumshoe
               gunman  ->  gunmen
            gymnasium  ->  gymnasiums|gymnasia
    TODO:siverb              had  ->  had
    TODO:siverb      had thought  ->  had thought
            Hainanese  ->  Hainanese
    TODO:siverb       hammertoes  ->  hammertoe
         handkerchief  ->  handkerchiefs
             Hararese  ->  Hararese
            Harlemese  ->  Harlemese
               harman  ->  harmans
            harmonium  ->  harmoniums
    TODO:siverb              has  ->  have
    TODO:siverb       has become  ->  have become
    TODO:siverb         has been  ->  have been
    TODO:siverb         has-been  ->  has-beens
               hasn't  ->  haven't                        # VERB FORM
             Havanese  ->  Havanese
    TODO:siverb             have  ->  have
    TODO:siverb    have conceded  ->  have conceded
    TODO:singular_noun 2 values               he  ->  they
         headquarters  ->  headquarters
            Heavenese  ->  Heavenese
                helix  ->  helices
            hepatitis  ->  hepatitises|hepatitides
    TODO:singular_noun 2 values              her  ->  them                           # PRONOUN
    TODO:singular_noun 2 values              her  ->  their                          # POSSESSIVE ADJ
                 hero  ->  heroes
               herpes  ->  herpes
    TODO:singular_noun 2 values             hers  ->  theirs                         # POSSESSIVE NOUN
    TODO:singular_noun 2 values          herself  ->  themselves
               hetman  ->  hetmans
               hiatus  ->  hiatuses|hiatus
            highlight  ->  highlights
              hijinks  ->  hijinks
    TODO:singular_noun 2 values              him  ->  them
    TODO:singular_noun 2 values          himself  ->  themselves
         hippopotamus  ->  hippopotamuses|hippopotami
           Hiroshiman  ->  Hiroshimans
    TODO:singular_noun 2 values              his  ->  their                          # POSSESSIVE ADJ
    TODO:singular_noun 2 values              his  ->  theirs                         # POSSESSIVE NOUN
    TODO:siverb             hoes  ->  hoe
           honorarium  ->  honorariums|honoraria
                 hoof  ->  hoofs|hooves
           Hoosierese  ->  Hoosierese
    TODO:siverb       horseshoes  ->  horseshoe
         Hottentotese  ->  Hottentotese
                house  ->  houses
            housewife  ->  housewives
               hubris  ->  hubrises
                human  ->  humans
             Hunanese  ->  Hunanese
                hydra  ->  hydras|hydrae
           hyperbaton  ->  hyperbata
            hyperbola  ->  hyperbolas|hyperbolae
                    I  ->  we
                 ibis  ->  ibises
            ignoramus  ->  ignoramuses
              impetus  ->  impetuses|impetus
              incubus  ->  incubuses|incubi
                index  ->  indexes|indices
          Indochinese  ->  Indochinese
              inferno  ->  infernos
              innings  ->  innings
   TODO:singular_noun Inspector General  ->  Inspectors General
          interregnum  ->  interregnums|interregna
                 iris  ->  irises|irides
       TODO:siverb            is  ->  are
       TODO:siverb      is eaten  ->  are eaten
                isn't  ->  aren't                         # VERB FORM
                   it  ->  they                           # NOMINATIVE
       TODO:siadj           its  ->  their                          # POSSESSIVE FORM
               itself  ->  themselves
           jackanapes  ->  jackanapes
             Japanese  ->  Japanese
             Javanese  ->  Javanese
                Jerry  ->  Jerrys
                jerry  ->  jerries
                 jinx  ->  jinxes
               jinxes  ->  jinx                           # VERB FORM
           Johnsonese  ->  Johnsonese
                Jones  ->  Joneses
                jumbo  ->  jumbos
             Kanarese  ->  Kanarese
           Kiplingese  ->  Kiplingese
                knife  ->  knives                         # NOUN FORM
                knife  ->  knife                          # VERB FORM (1st/2nd pers.)
               knifes  ->  knife                          # VERB FORM (3rd pers.)
             Kongoese  ->  Kongoese
            Kongolese  ->  Kongolese
               lacuna  ->  lacunas|lacunae
      lady in waiting  ->  ladies in waiting
            Lapponese  ->  Lapponese
               larynx  ->  larynxes|larynges
                latex  ->  latexes|latices
               lawman  ->  lawmen
               layman  ->  laymen
                 leaf  ->  leaves                         # NOUN FORM
                 leaf  ->  leaf                           # VERB FORM (1st/2nd pers.)
                leafs  ->  leaf                           # VERB FORM (3rd pers.)
             Lebanese  ->  Lebanese
                leman  ->  lemans
                lemma  ->  lemmas|lemmata
                 lens  ->  lenses
              Leonese  ->  Leonese
      lick of the cat  ->  licks of the cat
   Lieutenant General  ->  Lieutenant Generals
                 life  ->  lives
                Liman  ->  Limans
                lingo  ->  lingos
                 loaf  ->  loaves
                locus  ->  loci
            Londonese  ->  Londonese
           Lorrainese  ->  Lorrainese
             lothario  ->  lotharios
                louse  ->  lice
             Lucchese  ->  Lucchese
              lumbago  ->  lumbagos
                lumen  ->  lumens|lumina
               lummox  ->  lummoxes
              lustrum  ->  lustrums|lustra
               lyceum  ->  lyceums
             lymphoma  ->  lymphomas|lymphomata
                 lynx  ->  lynxes
              Lyonese  ->  Lyonese
   TODO:            M.I.A.  ->  M.I.A.s
             Macanese  ->  Macanese
          Macassarese  ->  Macassarese
             mackerel  ->  mackerel
                macro  ->  macros
     TODO:siverb            made  ->  made
               madman  ->  madmen
             Madurese  ->  Madurese
                magma  ->  magmas|magmata
              magneto  ->  magnetos
        Major General  ->  Major Generals
           Malabarese  ->  Malabarese
              Maltese  ->  Maltese
                  man  ->  men
             mandamus  ->  mandamuses
            manifesto  ->  manifestos
               mantis  ->  mantises
              marquis  ->  marquises
                 Mary  ->  Marys
              maximum  ->  maximums|maxima
              measles  ->  measles
               medico  ->  medicos
               medium  ->  mediums|media
   TODO:siadj          medium's  ->  mediums'|media's
               medusa  ->  medusas|medusae
           memorandum  ->  memorandums|memoranda
             meniscus  ->  menisci
               merman  ->  mermen
            Messinese  ->  Messinese
        metamorphosis  ->  metamorphoses
           metropolis  ->  metropolises
                 mews  ->  mews
               miasma  ->  miasmas|miasmata
             Milanese  ->  Milanese
               milieu  ->  milieus|milieux
           millennium  ->  millenniums|millennia
              minimum  ->  minimums|minima
                 minx  ->  minxes
                 miss  ->  miss                           # VERB FORM (1st/2nd pers.)
                 miss  ->  misses                         # NOUN FORM
               misses  ->  miss                           # VERB FORM (3rd pers.)
    TODO:siverb       mistletoes  ->  mistletoe
             mittamus  ->  mittamuses
             Modenese  ->  Modenese
             momentum  ->  momentums|momenta
                money  ->  monies
             mongoose  ->  mongooses
                moose  ->  moose
        mother-in-law  ->  mothers-in-law
                mouse  ->  mice
                mumps  ->  mumps
             Muranese  ->  Muranese
                murex  ->  murices
               museum  ->  museums
            mustachio  ->  mustachios
   TODO:siadj                my  ->  our                            # POSSESSIVE FORM
               myself  ->  ourselves
               mythos  ->  mythoi
            Nakayaman  ->  Nakayamans
           Nankingese  ->  Nankingese
           nasturtium  ->  nasturtiums
            Navarrese  ->  Navarrese
               nebula  ->  nebulas|nebulae
             Nepalese  ->  Nepalese
             neuritis  ->  neuritises|neuritides
             neurosis  ->  neuroses
                 news  ->  news
                nexus  ->  nexus
              Niasese  ->  Niasese
           Nicobarese  ->  Nicobarese
               nimbus  ->  nimbuses|nimbi
            Nipponese  ->  Nipponese
                   no  ->  noes
               Norman  ->  Normans
              nostrum  ->  nostrums
             noumenon  ->  noumena
                 nova  ->  novas|novae
            nucleolus  ->  nucleoluses|nucleoli
              nucleus  ->  nuclei
                numen  ->  numina
                  oaf  ->  oafs
    TODO:siverb            oboes  ->  oboe
              occiput  ->  occiputs|occipita
               octavo  ->  octavos
              octopus  ->  octopuses|octopodes
               oedema  ->  oedemas|oedemata
            Oklahoman  ->  Oklahomans
              omnibus  ->  omnibuses
                on it  ->  on them                        # ACCUSATIVE
                 onus  ->  onuses
                opera  ->  operas
              optimum  ->  optimums|optima
                 opus  ->  opuses|opera
              organon  ->  organa
              ottoman  ->  ottomans
          ought to be  ->  ought to be                    # VERB (UNLIKE bride to be)
     TODO:siverb       overshoes  ->  overshoe
     TODO:siverb        overtoes  ->  overtoe
                 ovum  ->  ova
                   ox  ->  oxen
     TODO:siadj            ox's  ->  oxen's                         # POSSESSIVE FORM
                oxman  ->  oxmen
             oxymoron  ->  oxymorons|oxymora
              Panaman  ->  Panamans
             parabola  ->  parabolas|parabolae
              Parmese  ->  Parmese
               pathos  ->  pathoses
              pegasus  ->  pegasuses
            Pekingese  ->  Pekingese
               pelvis  ->  pelvises
             pendulum  ->  pendulums
                penis  ->  penises|penes
             penumbra  ->  penumbras|penumbrae
           perihelion  ->  perihelia
               person  ->  people|persons
              persona  ->  personae
            petroleum  ->  petroleums
              phalanx  ->  phalanxes|phalanges
                  PhD  ->  PhDs
           phenomenon  ->  phenomena
             philtrum  ->  philtrums
                photo  ->  photos
               phylum  ->  phylums|phyla
                piano  ->  pianos|piani
          Piedmontese  ->  Piedmontese
                 pika  ->  pikas
   TODO:singular_noun ret mul value            pincer  ->  pincers
              pincers  ->  pincers
            Pistoiese  ->  Pistoiese
              plateau  ->  plateaus|plateaux
                 play  ->  plays
               plexus  ->  plexuses|plexus
               pliers  ->  pliers
                plies  ->  ply                            # VERB FORM
                polis  ->  polises
             Polonese  ->  Polonese
             pontifex  ->  pontifexes|pontifices
          portmanteau  ->  portmanteaus|portmanteaux
           Portuguese  ->  Portuguese
               possum  ->  possums
               potato  ->  potatoes
                  pox  ->  pox
               pragma  ->  pragmas|pragmata
              premium  ->  premiums
          prima donna  ->  prima donnas|prime donne
                  pro  ->  pros
          proceedings  ->  proceedings
         prolegomenon  ->  prolegomena
                proof  ->  proofs
     proof of concept  ->  proofs of concept
          prosecutrix  ->  prosecutrixes|prosecutrices
           prospectus  ->  prospectuses|prospectus
            protozoan  ->  protozoans
            protozoon  ->  protozoa
                 puma  ->  pumas
     TODO:siverb             put  ->  put
              quantum  ->  quantums|quanta
 TODO:singular_noun quartermaster general  ->  quartermasters general
               quarto  ->  quartos
                 quiz  ->  quizzes
              quizzes  ->  quiz                           # VERB FORM
               quorum  ->  quorums
               rabies  ->  rabies
               radius  ->  radiuses|radii
                radix  ->  radices
               ragman  ->  ragmen
                rebus  ->  rebuses
   TODO:siverb            rehoes  ->  rehoe
             reindeer  ->  reindeer
   TODO:siverb           reshoes  ->  reshoe
                rhino  ->  rhinos
           rhinoceros  ->  rhinoceroses|rhinoceros
   TODO:siverb              roes  ->  roe
                  Rom  ->  Roma
            Romagnese  ->  Romagnese
                Roman  ->  Romans
             Romanese  ->  Romanese
               Romany  ->  Romanies
                romeo  ->  romeos
                 roof  ->  roofs
              rostrum  ->  rostrums|rostra
               ruckus  ->  ruckuses
               salmon  ->  salmon
            Sangirese  ->  Sangirese
   TODO: siverb              sank  ->  sank
           Sarawakese  ->  Sarawakese
              sarcoma  ->  sarcomas|sarcomata
            sassafras  ->  sassafrases
                  saw  ->  saw                            # VERB FORM (1st/2nd pers.)
                  saw  ->  saws                           # NOUN FORM
                 saws  ->  saw                            # VERB FORM (3rd pers.)
                scarf  ->  scarves
               schema  ->  schemas|schemata
             scissors  ->  scissors
             Scotsman  ->  Scotsmen
             sea-bass  ->  sea-bass
               seaman  ->  seamen
                 self  ->  selves
               Selman  ->  Selmans
           Senegalese  ->  Senegalese
               seraph  ->  seraphs|seraphim
               series  ->  series
    TODO:siverb        shall eat  ->  shall eat
               shaman  ->  shamans
              Shavese  ->  Shavese
            Shawanese  ->  Shawanese
    TODO:singular_noun multivalue              she  ->  they
                sheaf  ->  sheaves
               shears  ->  shears
                sheep  ->  sheep
                shelf  ->  shelves
   TODO:siverb             shoes  ->  shoe
   TODO:siverb       should have  ->  should have
              Siamese  ->  Siamese
              siemens  ->  siemens
              Sienese  ->  Sienese
            Sikkimese  ->  Sikkimese
                silex  ->  silices
              simplex  ->  simplexes|simplices
           Singhalese  ->  Singhalese
            Sinhalese  ->  Sinhalese
                sinus  ->  sinuses|sinus
                 size  ->  sizes
                sizes  ->  size                           #VERB FORM
             smallpox  ->  smallpox
                Smith  ->  Smiths
   TODO:siverb         snowshoes  ->  snowshoe
           Sogdianese  ->  Sogdianese
            soliloquy  ->  soliloquies
                 solo  ->  solos|soli
                 soma  ->  somas|somata
   TODO:singular_noun tough    son of a bitch  ->  sons of bitches
              Sonaman  ->  Sonamans
              soprano  ->  sopranos|soprani
   TODO:siverb            sought  ->  sought
   TODO:siverb       spattlehoes  ->  spattlehoe
              species  ->  species
             spectrum  ->  spectrums|spectra
             speculum  ->  speculums|specula
   TODO:siverb             spent  ->  spent
         spermatozoon  ->  spermatozoa
               sphinx  ->  sphinxes|sphinges
         spokesperson  ->  spokespeople|spokespersons
              stadium  ->  stadiums|stadia
               stamen  ->  stamens|stamina
               status  ->  statuses|status
               stereo  ->  stereos
               stigma  ->  stigmas|stigmata
             stimulus  ->  stimuli
                stoma  ->  stomas|stomata
              stomach  ->  stomachs
               storey  ->  storeys
                story  ->  stories
              stratum  ->  strata
               strife  ->  strifes
                stylo  ->  stylos
               stylus  ->  styluses|styli
             succubus  ->  succubuses|succubi
             Sudanese  ->  Sudanese
               suffix  ->  suffixes
            Sundanese  ->  Sundanese
             superior  ->  superiors
  TODO:singular_noun    Surgeon-General  ->  Surgeons-General
              surplus  ->  surpluses
            Swahilese  ->  Swahilese
                swine  ->  swines|swine
      TODO:singular_noun multiple return        syringe  ->  syringes
               syrinx  ->  syrinxes|syringes
              tableau  ->  tableaus|tableaux
              Tacoman  ->  Tacomans
              talouse  ->  talouses
               tattoo  ->  tattoos
               taxman  ->  taxmen
                tempo  ->  tempos|tempi
           Tenggerese  ->  Tenggerese
            testatrix  ->  testatrixes|testatrices
               testes  ->  testes
      TODO:singular_noun multiple return         testis  ->  testes
      TODO:siadj           that  ->  those
      TODO:siadj          their  ->  their                          # POSSESSIVE FORM (GENDER-INCLUSIVE)
      TODO:singular_noun multiple return       themself  ->  themselves                     # ugly but gaining currency
      TODO:singular_noun multiple return           they  ->  they                           # for indeterminate gender
                thief  ->  thiefs|thieves
      TODO:siadj           this  ->  these
              thought  ->  thoughts                       # NOUN FORM
              thought  ->  thought                        # VERB FORM
      TODO:siverb         throes  ->  throe
      TODO:siverb   ticktacktoes  ->  ticktacktoe
                Times  ->  Timeses
             Timorese  ->  Timorese
      TODO:siverb        tiptoes  ->  tiptoe
             Tirolese  ->  Tirolese
             titmouse  ->  titmice
      TODO:singular_noun multivalue         to her  ->  to them
      TODO:singular_noun multivalue     to herself  ->  to themselves
      TODO:singular_noun multivalue         to him  ->  to them
      TODO:singular_noun multivalue     to himself  ->  to themselves
                to it  ->  to them
                to it  ->  to them                        # ACCUSATIVE
            to itself  ->  to themselves
                to me  ->  to us
            to myself  ->  to ourselves
      TODO:singular_noun multivalue        to them  ->  to them                        # for indeterminate gender
      TODO:singular_noun multivalue    to themself  ->  to themselves                  # ugly but gaining currency
               to you  ->  to you
          to yourself  ->  to yourselves
            Tocharese  ->  Tocharese
      TODO:siverb           toes  ->  toe
               tomato  ->  tomatoes
            Tonkinese  ->  Tonkinese
          tonsillitis  ->  tonsillitises|tonsillitides
                tooth  ->  teeth
             Torinese  ->  Torinese
                torus  ->  toruses|tori
            trapezium  ->  trapeziums|trapezia
               trauma  ->  traumas|traumata
              travois  ->  travois
              trellis  ->  trellises
     TODO:siverb           tries  ->  try
               trilby  ->  trilbys
             trousers  ->  trousers
            trousseau  ->  trousseaus|trousseaux
                trout  ->  trout
      TODO:siverb            try  ->  tries
                 tuna  ->  tuna
                 turf  ->  turfs|turves
             Tyrolese  ->  Tyrolese
            ultimatum  ->  ultimatums|ultimata
            umbilicus  ->  umbilicuses|umbilici
                umbra  ->  umbras|umbrae
      TODO:siverb     undershoes  ->  undershoe
      TODO:siverb        unshoes  ->  unshoe
               uterus  ->  uteruses|uteri
               vacuum  ->  vacuums|vacua
               vellum  ->  vellums
                velum  ->  velums|vela
           Vermontese  ->  Vermontese
             Veronese  ->  Veronese
             vertebra  ->  vertebrae
               vertex  ->  vertexes|vertices
             Viennese  ->  Viennese
           Vietnamese  ->  Vietnamese
             virtuoso  ->  virtuosos|virtuosi
                virus  ->  viruses
                vixen  ->  vixens
               vortex  ->  vortexes|vortices
               walrus  ->  walruses
   TODO:siverb               was  ->  were
   TODO:siverb    was faced with  ->  were faced with
   TODO:siverb        was hoping  ->  were hoping
           Wenchowese  ->  Wenchowese
   TODO:siverb              were  ->  were
   TODO:siverb        were found  ->  were found
                wharf  ->  wharves
              whiting  ->  whiting
           Whitmanese  ->  Whitmanese
                 whiz  ->  whizzes
   TODO:singular_noun multivalue             whizz  ->  whizzes
               widget  ->  widgets
                 wife  ->  wives
           wildebeest  ->  wildebeests|wildebeest
                 will  ->  will                           # VERB FORM
                 will  ->  wills                          # NOUN FORM
             will eat  ->  will eat                       # VERB FORM
                wills  ->  will                           # VERB FORM
                 wish  ->  wishes
   TODO:singular_noun multivalue          with him  ->  with them
              with it  ->  with them                      # ACCUSATIVE
   TODO:siverb              woes  ->  woe
                 wolf  ->  wolves
                woman  ->  women
   woman of substance  ->  women of substance
    TODO:siadj          woman's  ->  women's                        # POSSESSIVE FORM
                won't  ->  won't                          # VERB FORM
            woodlouse  ->  woodlice
              Yakiman  ->  Yakimans
             Yengeese  ->  Yengeese
               yeoman  ->  yeomen
             yeowoman  ->  yeowomen
                  yes  ->  yeses
            Yokohaman  ->  Yokohamans
                  you  ->  you
   TODO:siadj              your  ->  your                           # POSSESSIVE FORM
             yourself  ->  yourselves
                Yuman  ->  Yumans
            Yunnanese  ->  Yunnanese
                 zero  ->  zeros
                 zoon  ->  zoa
'''.split('\n')



from nose.tools import eq_

import inflect


def test_ancient_1():
    p = inflect.engine()

    # DEFAULT...

    eq_(p.plural_noun('person'),     'people',      msg="classical 'persons' not active")

    # "person" PLURALS ACTIVATED...

    p.classical(persons=True)
    eq_(p.plural_noun('person'),     'persons',     msg="classical 'persons' active")

    # OTHER CLASSICALS NOT ACTIVATED...

    eq_(p.plural_noun('wildebeest'), 'wildebeests', msg="classical 'herd' not active")
    eq_(p.plural_noun('formula'),    'formulas',    msg="classical 'ancient' active")
    eq_(p.plural_noun('error', 0),   'errors',      msg="classical 'zero' not active")
    eq_(p.plural_noun('brother'),    'brothers',    msg="classical 'all' not active")
    eq_(p.plural_noun('Sally'),      'Sallys',      msg="classical 'names' active")
    eq_(p.plural_noun('Jones', 0),   'Joneses',     msg="classical 'names' active")



from nose.tools import eq_

import inflect


def test_an():
    p = inflect.engine()

    eq_(p.an('cat'), 'a cat', msg='a cat')
    eq_(p.an('ant'), 'an ant', msg='an ant')
    eq_(p.an('a'), 'an a', msg='an a')
    eq_(p.an('b'), 'a b', msg='a b')
    eq_(p.an('honest cat'), 'an honest cat', msg='an honest')
    eq_(p.an('dishonest cat'), 'a dishonest cat', msg='a dishonest')
    eq_(p.an('Honolulu sunset'), 'a Honolulu sunset', msg='a Honolulu')
    eq_(p.an('mpeg'), 'an mpeg', msg='an mpeg')
    eq_(p.an('onetime holiday'), 'a onetime holiday', msg='a onetime')
    eq_(p.an('Ugandan person'), 'a Ugandan person', msg='a Ugandan')
    eq_(p.an('Ukranian person'), 'a Ukranian person', msg='a Ukranian')
    eq_(p.an('Unabomber'), 'a Unabomber', msg='a Unabomber')
    eq_(p.an('unanimous decision'), 'a unanimous decision', msg='a unanimous')
    eq_(p.an('US farmer'), 'a US farmer', msg='a US')




# use nosetest to run these tests

from nose.tools import eq_

import inflect

FNAME = 'tests/words.txt'
# FNAME = 'tests/list-of-nouns.txt'
# FNAME = '/usr/share/dict/british-english'
# FNAME = 'tricky.txt'


def getwords():
    words = open(FNAME).readlines()
    words = [w.strip() for w in words]
    return words


def test_pl_si():
    p = inflect.engine()
    words = getwords()
    for word in words:
        if word == '':
            continue
        if word[-2:] == "'s":
            continue
#        if word[-1] == 's':
#            continue
        p.classical(all=False)
        yield check_pl_si, p, word
        p.classical(all=True)
        yield check_pl_si, p, word


def check_pl_si(p, word):
    if p.singular_noun(p.plural_noun(word, 2), 1) != word:
        f = open('badsi.txt', 'a')
        f.write('%s %s %s\n' % (word, p.plural_noun(word, 2),
                                p.singular_noun(p.plural_noun(word, 2), 1)))
        f.close()
        eq_(p.singular_noun(p.plural_noun(word, 2), 1), word,
            msg='''word==%s
plnoun(%s)==%s
sinoun(%s)==%s''' % (word,
            word, p.plural_noun(word, 2),
            p.plural_noun(word, 2), p.singular_noun(p.plural_noun(word, 2), 1)))



import os

import inflect

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


here = os.path.dirname(__file__)
readme_path = os.path.join(here, 'README.rst')
readme = open(readme_path, 'rb').read().decode('utf-8')

setup(
    name='inflect',
    version=inflect.__version__,
    description='Correctly generate plurals, singular nouns, ordinals, indefinite articles; convert numbers to words',
    long_description=readme,
    author='Paul Dyson',
    author_email='pwdyson@yahoo.com',
    maintainer='Alex Gronholm',
    maintainer_email='alex.gronholm@nextday.fi',
    url='http://pypi.python.org/pypi/inflect',
    py_modules=['inflect'],
    provides=['inflect'],
    keywords=['plural', 'inflect', 'participle'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU Affero General Public License v3',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Text Processing :: Linguistic',
    ]
)
